@@ -83,7 +83,6 @@ class WirecloudTemplateParser(object):
 
         self._info = {}
         self._translation_indexes = {}
-        self._url_fields = []
 
         if isinstance(template, str):
             self._doc = etree.fromstring(template)
@@ -162,12 +161,6 @@ class WirecloudTemplateParser(object):
             msg = _('missing required field: %(field)s')
             raise TemplateParseException(msg % {'field': xpath})
 
-    def _get_url_field(self, field, *args, **kwargs):
-
-        value = self._get_field(*args, **kwargs)
-        self._url_fields.append(field)
-        self._info[field] = value
-
     def _parse_basic_info(self):
 
         self._info['vendor'] = self._get_field(VENDOR_XPATH, self._resource_description).strip()
@@ -193,8 +186,9 @@ class WirecloudTemplateParser(object):
 
         self._info['author'] = self._get_field(AUTHOR_XPATH, self._resource_description, required=False)
         self._info['email'] = self._get_field(MAIL_XPATH, self._resource_description)
-        self._get_url_field('image_uri', IMAGE_URI_XPATH, self._resource_description, required=False)
-        self._get_url_field('doc_uri', DOC_URI_XPATH, self._resource_description, required=False)
+        self._info['image_uri'] = self._get_field(IMAGE_URI_XPATH, self._resource_description, required=False)
+        self._info['iphone_image_uri'] = self._get_field(IPHONE_IMAGE_URI_XPATH, self._resource_description, required=False)
+        self._info['doc_uri'] = self._get_field(DOC_URI_XPATH, self._resource_description, required=False)
         self._parse_requirements()
 
     def _parse_requirements(self):
@@ -252,6 +246,7 @@ class WirecloudTemplateParser(object):
         if parse_connections:
             self._parse_wiring_connection_info(wiring_element)
             self._parse_wiring_operator_info(wiring_element)
+            self._info['wiring']['views'] = []
 
     def _parse_wiring_connection_info(self, wiring_element):
 
@@ -309,12 +304,10 @@ class WirecloudTemplateParser(object):
 
     def _parse_widget_info(self):
 
-        self._get_url_field('iphone_image_uri', IPHONE_IMAGE_URI_XPATH, self._resource_description, required=False)
-
         self._info['preferences'] = []
         for preference in self._xpath(PREFERENCES_XPATH, self._doc):
-            self._add_translation_index(preference.get('label'), type='vdef', variable=preference.get('name'))
-            self._add_translation_index(preference.get('description', ''), type='vdef', variable=preference.get('name'))
+            self._add_translation_index(preference.get('label'), type='vdef', variable=preference.get('name'), field='label')
+            self._add_translation_index(preference.get('description', ''), type='vdef', variable=preference.get('name'), field='description')
             preference_info = {
                 'name': preference.get('name'),
                 'type': preference.get('type'),
@@ -328,9 +321,9 @@ class WirecloudTemplateParser(object):
 
             if preference_info['type'] == 'list':
                 preference_info['options'] = []
-                for option in self._xpath(OPTION_XPATH, preference):
+                for option_index, option in enumerate(self._xpath(OPTION_XPATH, preference)):
                     option_label = option.get('label', option.get('name'))
-                    self._add_translation_index(option_label, type='upo', variable=preference.get('name'), option=option_label)
+                    self._add_translation_index(option_label, type='upo', variable=preference.get('name'), option=option_index)
                     preference_info['options'].append({
                         'label': option_label,
                         'value': option.get('value'),
@@ -384,6 +377,7 @@ class WirecloudTemplateParser(object):
             raise TemplateParseException(msg)
 
         self._info['code_content_type'] = xhtml_element.get('content-type', 'text/html')
+        self._info['code_charset'] = xhtml_element.get('charset', 'utf-8')
         self._info['code_uses_platform_style'] = xhtml_element.get('use-platform-style', 'false').lower() == 'true'
         self._info['code_cacheable'] = xhtml_element.get('cacheable', 'true').lower() == 'true'
 
@@ -437,6 +431,8 @@ class WirecloudTemplateParser(object):
                         'z': position.get('z'),
                     },
                     'rendering': {
+                        'fulldragboard': rendering.get('fulldragboard', 'false').lower() == 'true',
+                        'minimized': rendering.get('minimized', 'false').lower() == 'true',
                         'width': rendering.get('width'),
                         'height': rendering.get('height'),
                         'layout': rendering.get('layout'),
