@@ -19,6 +19,9 @@
 
 import rdflib
 
+from wirecloud.commons.utils.translation import replace_trans_index
+
+
 WIRE = rdflib.Namespace("http://wirecloud.conwet.fi.upm.es/ns/widget#")
 WIRE_M = rdflib.Namespace("http://wirecloud.conwet.fi.upm.es/ns/mashup#")
 FOAF = rdflib.Namespace('http://xmlns.com/foaf/0.1/')
@@ -42,6 +45,24 @@ GR = rdflib.Namespace('http://purl.org/goodrelations/v1#')
 DOAP = rdflib.Namespace('http://usefulinc.com/ns/doap#')
 
 
+def add_translated_nodes(graph, parent_node, namespace, element_name, value, usage, template_info):
+
+    used_translation_vars = []
+    for translation_var_name, translation_var_usage in template_info['translation_index_usage'].iteritems():
+        if usage in translation_var_usage:
+            used_translation_vars.append(translation_var_name)
+
+    if len(used_translation_vars) > 0:
+        for lang, catalogue in template_info['translations'].iteritems():
+            msg = value
+            for translation_var_name in used_translation_vars:
+                msg = replace_trans_index(translation_var_name, catalogue[translation_var_name], msg)
+
+            graph.add((parent_node, namespace[element_name], rdflib.Literal(msg, lang=lang)))
+    else:
+        graph.add((parent_node, namespace[element_name], rdflib.Literal(value)))
+
+
 def write_wiring_views_graph(graph, wiring, template_info):
 
     for view in template_info['wiring']['views']:
@@ -112,12 +133,12 @@ def write_mashup_resources_graph(graph, resource_uri, template_info):
         graph.add((tab_element, DCTERMS['title'], rdflib.Literal(tab['name'])))
         graph.add((tab_element, WIRE['index'], rdflib.Literal(str(tab_index))))
 
-        for preference in tab['preferences']:
+        for preference_name in tab['preferences']:
             pref = rdflib.BNode()
             graph.add((pref, rdflib.RDF.type, WIRE_M['TabPreference']))
             graph.add((tab_element, WIRE_M['hasTabPreference'], pref))
-            graph.add((pref, DCTERMS['title'], rdflib.Literal(preference.name)))
-            graph.add((pref, WIRE['value'], rdflib.Literal(preference.value)))
+            graph.add((pref, DCTERMS['title'], rdflib.Literal(preference_name)))
+            graph.add((pref, WIRE['value'], rdflib.Literal(tab['preferences'][preference_name])))
 
         for iwidget in tab['resources']:
             resource = rdflib.BNode()
@@ -251,7 +272,7 @@ def build_rdf_graph(template_info):
     graph.add((provider, FOAF['name'], rdflib.Literal(template_info.get('vendor'))))
     graph.add((resource_uri, USDL['versionInfo'], rdflib.Literal(template_info.get('version'))))
     graph.add((resource_uri, DCTERMS['title'], rdflib.Literal(template_info.get('name'))))
-    graph.add((resource_uri, DCTERMS['description'], rdflib.Literal(template_info.get('description'))))
+    add_translated_nodes(graph, resource_uri, DCTERMS, 'description', template_info.get('description'), {'type': 'resource', 'field': 'description'}, template_info)
 
     author = rdflib.BNode()
     graph.add((author, rdflib.RDF.type, FOAF['Person']))
@@ -263,7 +284,7 @@ def build_rdf_graph(template_info):
     if template_info.get('doc_uri'):
         graph.add((resource_uri, FOAF['page'], rdflib.URIRef(template_info.get('doc_uri'))))
 
-    graph.add((resource_uri, WIRE['displayName'], rdflib.Literal(template_info.get('display_name', template_info.get('name')))))
+    add_translated_nodes(graph, resource_uri, WIRE, 'displayName', template_info.get('display_name', ''), {'type': 'resource', 'field': 'display_name'}, template_info)
 
     addr = rdflib.BNode()
     graph.add((addr, rdflib.RDF.type, VCARD['Work']))
@@ -289,27 +310,29 @@ def build_rdf_graph(template_info):
         graph.add((resource_uri, WIRE['hasPlatformWiring'], wiring))
 
     # Output endpoints
-    for output_endpoint in template_info['wiring']['outputs']:
+    for output_index, output_endpoint in enumerate(template_info['wiring']['outputs']):
         output_node = rdflib.BNode()
         graph.add((output_node, rdflib.RDF.type, WIRE['OutputEndpoint']))
         graph.add((wiring, WIRE['hasOutputEndpoint'], output_node))
+        graph.add((output_node, WIRE['index'], rdflib.Literal(str(output_index))))
         graph.add((output_node, DCTERMS['title'], rdflib.Literal(output_endpoint.get('name'))))
-        graph.add((output_node, RDFS['label'], rdflib.Literal(output_endpoint.get('label'))))
+        add_translated_nodes(graph, output_node, RDFS, 'label', output_endpoint.get('label'), {'type': 'vdef', 'variable': output_endpoint.get('name'), 'field': 'label'}, template_info)
+        add_translated_nodes(graph, output_node, DCTERMS, 'description', output_endpoint.get('description'), {'type': 'vdef', 'variable': output_endpoint.get('name'), 'field': 'description'}, template_info)
         graph.add((output_node, WIRE['type'], rdflib.Literal(output_endpoint.get('type'))))
         graph.add((output_node, WIRE['friendcode'], rdflib.Literal(output_endpoint.get('friendcode'))))
-        graph.add((output_node, DCTERMS['description'], rdflib.Literal(output_endpoint.get('description'))))
 
     # Input endpoints
-    for input_endpoint in template_info['wiring']['inputs']:
+    for input_index, input_endpoint in enumerate(template_info['wiring']['inputs']):
         input_node = rdflib.BNode()
         graph.add((input_node, rdflib.RDF.type, WIRE['InputEndpoint']))
         graph.add((wiring, WIRE['hasInputEndpoint'], input_node))
+        graph.add((input_node, WIRE['index'], rdflib.Literal(str(input_index))))
         graph.add((input_node, DCTERMS['title'], rdflib.Literal(input_endpoint.get('name'))))
-        graph.add((input_node, RDFS['label'], rdflib.Literal(input_endpoint.get('label'))))
+        add_translated_nodes(graph, input_node, RDFS, 'label', input_endpoint.get('label'), {'type': 'vdef', 'variable': input_endpoint.get('name'), 'field': 'label'}, template_info)
+        add_translated_nodes(graph, input_node, DCTERMS, 'description', input_endpoint.get('description'), {'type': 'vdef', 'variable': input_endpoint.get('name'), 'field': 'description'}, template_info)
         graph.add((input_node, WIRE['type'], rdflib.Literal(input_endpoint.get('type'))))
         graph.add((input_node, WIRE['friendcode'], rdflib.Literal(input_endpoint.get('friendcode'))))
-        graph.add((input_node, DCTERMS['description'], rdflib.Literal(input_endpoint.get('description'))))
-        graph.add((input_node, WIRE['inputActionLabel'], rdflib.Literal(input_endpoint.get('action_label'))))
+        add_translated_nodes(graph, input_node, WIRE, 'inputActionLabel', input_endpoint.get('actionlabel'), {'type': 'vdef', 'variable': input_endpoint.get('name'), 'field': 'actionlabel'}, template_info)
 
     if template_info['type'] == 'mashup':
         write_mashup_wiring_graph(graph, wiring, template_info)
@@ -319,12 +342,12 @@ def build_rdf_graph(template_info):
 
     if template_info['type'] == 'mashup':
         # Mashup preferences
-        for pref_index, pref in enumerate(template_info['preferences']):
+        for pref_name, pref_value in template_info['preferences'].iteritems():
             pref = rdflib.BNode()
             graph.add((pref, rdflib.RDF.type, WIRE_M['MashupPreference']))
             graph.add((resource_uri, WIRE_M['hasMashupPreference'], pref))
-            graph.add((pref, DCTERMS['title'], rdflib.Literal(pref['name'])))
-            graph.add((pref, WIRE['value'], rdflib.Literal(pref['value'])))
+            graph.add((pref, DCTERMS['title'], rdflib.Literal(pref_name)))
+            graph.add((pref, WIRE['value'], rdflib.Literal(pref_value)))
     else:
         # Platform preferences
         for pref_index, pref in enumerate(template_info['preferences']):
@@ -334,13 +357,13 @@ def build_rdf_graph(template_info):
             graph.add((pref_node, WIRE['index'], rdflib.Literal(str(pref_index))))
             graph.add((pref_node, DCTERMS['title'], rdflib.Literal(pref.get('name'))))
             graph.add((pref_node, WIRE['type'], rdflib.Literal(pref.get('type'))))
-            graph.add((pref_node, RDFS['label'], rdflib.Literal(pref.get('label'))))
-            graph.add((pref_node, DCTERMS['description'], rdflib.Literal(pref.get('description'))))
+            add_translated_nodes(graph, pref_node, RDFS, 'label', pref.get('label'), {'type': 'vdef', 'variable': pref.get('name'), 'field': 'label'}, template_info)
+            add_translated_nodes(graph, pref_node, DCTERMS, 'description', pref.get('description'), {'type': 'vdef', 'variable': pref.get('name'), 'field': 'description'}, template_info)
 
-            if pref.get('readonly', False) == True:
+            if pref.get('readonly', False) is True:
                 graph.add((pref_node, WIRE['readonly'], rdflib.Literal('true')))
 
-            if pref.get('default_value'):
+            if pref.get('default_value') not in (None, ''):
                 graph.add((pref_node, WIRE['default'], rdflib.Literal(pref.get('default_value'))))
 
             if pref.get('value'):
@@ -355,7 +378,7 @@ def build_rdf_graph(template_info):
                     graph.add((option_node, rdflib.RDF.type, WIRE['Option']))
                     graph.add((pref_node, WIRE['hasOption'], option_node))
                     graph.add((option_node, WIRE['index'], rdflib.Literal(str(option_index))))
-                    graph.add((option_node, DCTERMS['title'], rdflib.Literal(option.get('label'))))
+                    add_translated_nodes(graph, option_node, DCTERMS, 'title', option.get('label'), {'type': 'upo', 'variable': pref.get('name'), 'option': option_index}, template_info)
                     graph.add((option_node, WIRE['value'], rdflib.Literal(option.get('value'))))
 
         # Platform state properties
@@ -366,10 +389,10 @@ def build_rdf_graph(template_info):
             graph.add((prop_node, WIRE['index'], rdflib.Literal(str(prop_index))))
             graph.add((prop_node, DCTERMS['title'], rdflib.Literal(prop.get('name'))))
             graph.add((prop_node, WIRE['type'], rdflib.Literal(prop.get('type'))))
-            graph.add((prop_node, RDFS['label'], rdflib.Literal(prop.get('label'))))
-            graph.add((prop_node, DCTERMS['description'], rdflib.Literal(prop.get('description'))))
+            add_translated_nodes(graph, prop_node, RDFS, 'label', prop.get('label'), {'type': 'vdef', 'variable': prop.get('name'), 'field': 'label'}, template_info)
+            add_translated_nodes(graph, prop_node, DCTERMS, 'description', prop.get('description'), {'type': 'vdef', 'variable': prop.get('name'), 'field': 'description'}, template_info)
 
-            if prop.get('default_value'):
+            if prop.get('default_value') not in (None, ''):
                 graph.add((prop_node, WIRE['default'], rdflib.Literal(prop.get('default_value'))))
 
             if prop.get('secure'):
@@ -381,10 +404,11 @@ def build_rdf_graph(template_info):
         graph.add((xhtml_element, rdflib.RDF.type, USDL['Resource']))
         graph.add((resource_uri, USDL['utilizedResource'], xhtml_element))
 
-        if template_info['code_content_type'] != 'text/html':
-            graph.add((xhtml_element, DCTERMS['format'], rdflib.Literal(template_info.get('code_content_type'))))
+        if template_info['code_content_type'] != 'text/html' or template_info['code_charset'] != 'utf-8':
+            content_type = template_info.get('code_content_type', 'text/html') + '; charset=' + template_info.get('code_charset', 'utf-8').upper()
+            graph.add((xhtml_element, DCTERMS['format'], rdflib.Literal(content_type)))
 
-        if template_info['code_cacheable'] == False:
+        if template_info['code_cacheable'] is False:
             graph.add((xhtml_element, WIRE['codeCacheable'], rdflib.Literal('false')))
 
         if template_info['code_uses_platform_style']:
