@@ -109,7 +109,6 @@ def create_widget_from_template(template, user, request=None, base=None):
             description=preference['description'],
             type=parser.typeText2typeCode(preference['type']),
             aspect='PREF',
-            friend_code=None,
             readonly=preference['readonly'],
             label=preference['label'],
             default_value=preference['default_value'],
@@ -119,13 +118,13 @@ def create_widget_from_template(template, user, request=None, base=None):
         )
         variable_definitions[vDef.name] = vDef
         user_options[vDef.name] = {}
-        for option in preference.get('options', ()):
+        for option_index, option in enumerate(preference.get('options', ())):
             upo = UserPrefOption.objects.create(
                 value=option['value'],
                 name=option['label'],
                 variableDef=vDef
             )
-            user_options[vDef.name][upo.name] = upo
+            user_options[vDef.name][option_index] = upo
 
         order += 1
 
@@ -137,7 +136,6 @@ def create_widget_from_template(template, user, request=None, base=None):
             description=prop['description'],
             type=parser.typeText2typeCode(prop['type']),
             aspect='PROP',
-            friend_code=None,
             label=prop['label'],
             default_value=prop['default_value'],
             widget=widget,
@@ -253,18 +251,22 @@ def xpath(tree, query, xmlns):
         return tree.xpath(query, namespaces={'xhtml': xmlns})
 
 
-def fix_widget_code(widget_code, base_url, content_type, request, use_platform_style, force_base=False):
+def fix_widget_code(widget_code, base_url, content_type, request, encoding, use_platform_style, force_base=False):
+
+    # This line is here for raising UnicodeDecodeError in case the widget_code is not encoded using the expecified encoding
+    widget_code.decode(encoding)
 
     if content_type == 'text/html':
-        parser = etree.HTMLParser()
-        xmltree = etree.parse(StringIO(str(widget_code)), parser)
-        serialization_method = 'html'
+        parser = etree.HTMLParser(encoding=encoding)
+        serialization_options = {'method': 'html'}
     elif content_type == 'application/xhtml+xml':
-        xmltree = etree.fromstring(widget_code).getroottree()
-        serialization_method = 'xml'
+        parser = etree.XMLParser(encoding=encoding)
+        serialization_options = {'method': 'xml', 'xml_declaration': False}
     else:
         return widget_code
 
+    xmltree = etree.parse(StringIO(widget_code), parser)
+
     prefix = xmltree.getroot().prefix
     xmlns = None
     if prefix in xmltree.getroot().nsmap:
@@ -315,6 +317,7 @@ def fix_widget_code(widget_code, base_url, content_type, request, use_platform_s
         files.reverse()
         for file in files:
             head_element.insert(0, etree.Element('script', type="text/javascript", src=get_absolute_static_url(file, request=request)))
+        head_element.insert(0, etree.Element('script', type="text/javascript", src=get_absolute_static_url('js/WirecloudAPI/WirecloudAPICommon.js', request=request)))
         head_element.insert(0, etree.Element('script', type="text/javascript", src=get_absolute_static_url('js/WirecloudAPI/WirecloudAPI.js', request=request)))
 
         if use_platform_style:
@@ -328,4 +331,4 @@ def fix_widget_code(widget_code, base_url, content_type, request, use_platform_s
 
 
     # return modified code
-    return etree.tostring(xmltree, pretty_print=False, method=serialization_method)
+    return etree.tostring(xmltree, pretty_print=False, encoding=encoding, **serialization_options)
